@@ -8,15 +8,15 @@ class Consensus:
     """
     This file provides you with the consensus indicator and all associated helper methods.
 
-    The idea is based on the concept that, if you have 1 indicators telling you to buy
+    The idea is based on the concept that, if you have one indicator telling you to buy
     things are great.
-    if 100 indecators telling you to buy at the same time, things are better.
+    If 100 indicators are telling you to buy at the same time, things are better.
 
-    If we can now have an easily understandalbe score, things should be perfect.
+    If we can now have an easily understandable score, things should be perfect.
 
     Configuration:
 
-    each of the utility methods, utilizes the default parameters as based in the literature.
+    Each of the utility methods utilizes the default parameters as based in the literature.
     Assuming that these are the signals, most trades will use.
 
     Usage:
@@ -50,7 +50,7 @@ class Consensus:
 
     def __init__(self, dataframe: pd.DataFrame):
         """
-        initializes the conesensus object.
+        initializes the consensus object.
         :param dataframe: dataframe to evaluate
         """
         self.dataframe = dataframe.copy()
@@ -59,7 +59,7 @@ class Consensus:
 
     def _weights(self, impact_buy, impact_sell):
         """
-            helper method to compute total count of utilized indicators and their weigths
+        helper method to compute total count of utilized indicators and their weights
         :param impact_buy:
         :param impact_sell:
         :return:
@@ -70,6 +70,7 @@ class Consensus:
     def score(self, prefix="consensus", smooth=None):
         """
         this computes the consensus score, which should always be between 0 and 100
+        :param prefix:
         :param smooth: Allows to specify an integer for a smoothing interval
         :return:
         """
@@ -123,9 +124,8 @@ class Consensus:
 
     def evaluate_stoch(self, prefix="stoch", impact_buy=1, impact_sell=1):
         """
-        evaluates a s
+        evaluates the stochastic fast
         :param dataframe:
-        :param period:
         :param prefix:
         :return:
         """
@@ -141,10 +141,44 @@ class Consensus:
 
         dataframe.loc[((dataframe[f"{name}_fastk"] > 80)), f"sell_{name}"] = 1 * impact_sell
 
+    def evaluate_stoch_rsi(
+        self, period=14, smoothd=3, smoothk=3, prefix="stoch_rsi", impact_buy=1, impact_sell=1
+    ):
+        """
+        evaluates the stochastic rsi fast (TradingView version)
+        :param dataframe:
+        :param period:
+        :param prefix:
+        :return:
+        """
+
+        name = f"{prefix}_{period}"
+        self._weights(impact_buy, impact_sell)
+        dataframe = self.dataframe
+
+        # We don't use the talib.STOCHRSI library because it seems
+        # like the results are not identical to Trading View's version
+        dataframe[f"rsi_{period}"] = ta.RSI(dataframe, timeperiod=period)
+        stochrsi = (
+            dataframe[f"rsi_{period}"] - dataframe[f"rsi_{period}"].rolling(period).min()
+        ) / (
+            dataframe[f"rsi_{period}"].rolling(period).max()
+            - dataframe[f"rsi_{period}"].rolling(period).min()
+        )
+
+        dataframe[f"{name}_fastk"] = stochrsi.rolling(smoothk).mean() * 100
+        # The fastd below is not used
+        dataframe[f"{name}_fastd"] = dataframe[f"{name}_fastk"].rolling(smoothd).mean()
+
+        dataframe.loc[((dataframe[f"{name}_fastk"] < 20)), f"buy_{name}"] = 1 * impact_buy
+
+        dataframe.loc[((dataframe[f"{name}_fastk"] > 80)), f"sell_{name}"] = 1 * impact_sell
+
     def evaluate_macd_cross_over(self, prefix="macd_crossover", impact_buy=2, impact_sell=2):
         """
-            evaluates the MACD if we should buy or sale based on a crossover
+        evaluates the MACD if we should buy or sale based on a crossover
         :param dataframe:
+        :param prefix:
         :return:
         """
 
@@ -167,8 +201,9 @@ class Consensus:
 
     def evaluate_macd(self, prefix="macd", impact_buy=1, impact_sell=1):
         """
-            evaluates the MACD if we should buy or sale
+        evaluates the MACD if we should buy or sale
         :param dataframe:
+        :param prefix:
         :return:
         """
 
@@ -195,7 +230,7 @@ class Consensus:
 
     def evaluate_hull(self, period=9, field="close", prefix="hull", impact_buy=1, impact_sell=1):
         """
-        evaluates a tema moving average
+        evaluates a hull moving average
         :param dataframe:
         :param period:
         :param prefix:
@@ -212,7 +247,7 @@ class Consensus:
 
         dataframe.loc[((dataframe[name] < dataframe[field])), f"sell_{name}"] = 1 * impact_sell
 
-    def evaluate_vwma(self, period=9, prefix="hull", impact_buy=1, impact_sell=1):
+    def evaluate_vwma(self, period=9, prefix="vwma", impact_buy=1, impact_sell=1):
         """
         evaluates a volume weighted moving average
         :param dataframe:
@@ -284,7 +319,7 @@ class Consensus:
 
     def evaluate_laguerre(self, prefix="lag", impact_buy=1, impact_sell=1):
         """
-        evaluates the osc
+        evaluates the laguerre
         :param dataframe:
         :param period:
         :param prefix:
@@ -322,7 +357,7 @@ class Consensus:
 
     def evaluate_cmf(self, period=12, prefix="cmf", impact_buy=1, impact_sell=1):
         """
-        evaluates the osc
+        evaluates the cmf
         :param dataframe:
         :param period:
         :param prefix:
@@ -343,7 +378,7 @@ class Consensus:
         self, period=20, prefix="cci", impact_buy=1, impact_sell=1, sell_signal=100, buy_signal=-100
     ):
         """
-        evaluates the osc
+        evaluates the cci
         :param dataframe:
         :param period:
         :param prefix:
@@ -414,7 +449,7 @@ class Consensus:
 
     def evaluate_cmo(self, period=20, prefix="cmo", impact_buy=1, impact_sell=1):
         """
-        evaluates the osc
+        evaluates the cmo
         :param dataframe:
         :param period:
         :param prefix:
@@ -470,7 +505,7 @@ class Consensus:
 
     def evaluate_ultimate_oscilator(self, prefix="uo", impact_buy=1, impact_sell=1):
         """
-        evaluates the osc
+        evaluates the ultimate_oscilator
         :param dataframe:
         :param period:
         :param prefix:
@@ -487,7 +522,7 @@ class Consensus:
 
     def evaluate_williams(self, prefix="williams", impact_buy=1, impact_sell=1):
         """
-        evaluates the osc
+        evaluates the williams
         :param dataframe:
         :param period:
         :param prefix:
@@ -506,7 +541,7 @@ class Consensus:
 
     def evaluate_momentum(self, period=20, prefix="momentum", impact_buy=1, impact_sell=1):
         """
-        evaluates the osc
+        evaluates the momentum
         :param dataframe:
         :param period:
         :param prefix:
@@ -522,9 +557,79 @@ class Consensus:
 
         dataframe.loc[((dataframe[name] < 100)), f"sell_{name}"] = 1 * impact_sell
 
-    def evaluate_adx(self, period=14, prefix="momentum", impact_buy=1, impact_sell=1):
+    def evaluate_adx(
+        self, period=14, prefix="adx", trend_line=25, use_di=True, impact_buy=1, impact_sell=1
+    ):
         """
-        evaluates the osc
+        evaluates the adx (optionally use plus_di and minus_di to detect buy or sell)
+        :param dataframe:
+        :param period:
+        :param prefix:
+        :param trend_line: The ADX value at which we consider that a trend is present (Default: 25)
+        :param use_di: Enable/disable the usage of plus_di and minus_di (Default: Enabled)
+        :return:
+        """
+
+        self._weights(impact_buy, impact_sell)
+        dataframe = self.dataframe
+        name = f"{prefix}_{period}"
+        dataframe[name] = ta.ADX(dataframe, timeperiod=period)
+
+        # We can use PLUS_DI and MINUS_DI to be able to detect if we should buy or sell
+        # See https://www.investopedia.com/articles/trading/07/adx-trend-indicator.asp
+        if use_di:
+            dataframe[f"{name}_plus_di"] = ta.PLUS_DI(dataframe, timeperiod=period)
+            dataframe[f"{name}_minus_di"] = ta.MINUS_DI(dataframe, timeperiod=period)
+
+            dataframe.loc[
+                (
+                    (dataframe[name] > trend_line)
+                    & (dataframe[f"{name}_plus_di"] > dataframe[f"{name}_minus_di"])
+                ),
+                f"buy_{name}",
+            ] = (
+                1 * impact_buy
+            )
+
+            dataframe.loc[
+                (
+                    (dataframe[name] > trend_line)
+                    & (dataframe[f"{name}_plus_di"] < dataframe[f"{name}_minus_di"])
+                ),
+                f"sell_{name}",
+            ] = (
+                1 * impact_sell
+            )
+        else:
+            dataframe.loc[((dataframe[name] > trend_line)), f"buy_{name}"] = 1 * impact_buy
+
+            dataframe.loc[((dataframe[name] > trend_line)), f"sell_{name}"] = 1 * impact_sell
+
+    def evaluate_ao(self, prefix="ao", impact_buy=1, impact_sell=1):
+        """
+        evaluates the ao (Awesome Oscillator)
+        :param dataframe:
+        :param prefix:
+        :return:
+        """
+        from technical.qtpylib import awesome_oscillator
+
+        self._weights(impact_buy, impact_sell)
+        dataframe = self.dataframe
+        name = f"{prefix}"
+        dataframe[name] = awesome_oscillator(dataframe)
+
+        dataframe.loc[((dataframe[name] > (dataframe[name].shift(1) + 0.05))), f"buy_{name}"] = (
+            1 * impact_buy
+        )
+
+        dataframe.loc[((dataframe[name] < (dataframe[name].shift(1) - 0.05))), f"sell_{name}"] = (
+            1 * impact_sell
+        )
+
+    def evaluate_bbp(self, period=13, prefix="bbp", impact_buy=1, impact_sell=1):
+        """
+        evaluates the bbp (Bears Bulls Power)
         :param dataframe:
         :param period:
         :param prefix:
@@ -534,8 +639,28 @@ class Consensus:
         self._weights(impact_buy, impact_sell)
         dataframe = self.dataframe
         name = f"{prefix}_{period}"
-        dataframe[name] = ta.ADX(dataframe, timeperiod=period)
 
-        dataframe.loc[((dataframe[name] > 25)), f"buy_{name}"] = 1 * impact_buy
+        # Bears/Bulls Power is using EMA
+        dataframe[f"{name}_ema"] = ta.EMA(dataframe, timeperiod=period)
+        dataframe[f"{name}_bulls"] = dataframe["high"] - dataframe[f"{name}_ema"]
+        dataframe[f"{name}_bears"] = dataframe["low"] - dataframe[f"{name}_ema"]
 
-        dataframe.loc[((dataframe[name] > 25)), f"sell_{name}"] = 1 * impact_sell
+        dataframe.loc[
+            (
+                (dataframe[f"{name}_ema"] > dataframe[f"{name}_ema"].shift(1))
+                & (dataframe[f"{name}_bulls"] > dataframe[f"{name}_bulls"].shift(1))
+            ),
+            f"buy_{name}",
+        ] = (
+            1 * impact_buy
+        )
+
+        dataframe.loc[
+            (
+                (dataframe[f"{name}_ema"] < dataframe[f"{name}_ema"].shift(1))
+                & (dataframe[f"{name}_bears"] > dataframe[f"{name}_bears"].shift(1))
+            ),
+            f"sell_{name}",
+        ] = (
+            1 * impact_sell
+        )
