@@ -2,6 +2,8 @@
 This file contains a collection of common indicators,
 which are based on third party or custom libraries
 """
+import math
+
 import numpy as np
 from numpy.core.records import ndarray
 from pandas import DataFrame, Series
@@ -29,6 +31,16 @@ def ichimoku(
     Note: Do not use chikou_span for backtesting.
         It looks into the future, is not printed by most charting platforms.
         It is only useful for visual analysis
+
+    Usage:
+        ichi = ichimoku(dataframe)
+        dataframe['tenkan_sen'] = ichi['tenkan_sen']
+        dataframe['kijun_sen'] = ichi['kijun_sen']
+        dataframe['senkou_span_a'] = ichi['senkou_span_a']
+        dataframe['senkou_span_b'] = ichi['senkou_span_b']
+        dataframe['cloud_green'] = ichi['cloud_green']
+        dataframe['cloud_red'] = ichi['cloud_red']
+
     :param dataframe: Dataframe containing OHLCV data
     :param conversion_line_period: Conversion line Period (defaults to 9)
     :param base_line_periods: Base line Periods (defaults to 26)
@@ -56,11 +68,11 @@ def ichimoku(
         + dataframe["low"].rolling(window=laggin_span).min()
     ) / 2
 
-    senkou_span_a = leading_senkou_span_a.shift(displacement)
+    senkou_span_a = leading_senkou_span_a.shift(displacement - 1)
 
-    senkou_span_b = leading_senkou_span_b.shift(displacement)
+    senkou_span_b = leading_senkou_span_b.shift(displacement - 1)
 
-    chikou_span = dataframe["close"].shift(-displacement)
+    chikou_span = dataframe["close"].shift(-displacement + 1)
 
     cloud_green = senkou_span_a > senkou_span_b
     cloud_red = senkou_span_b > senkou_span_a
@@ -707,7 +719,6 @@ def vfi(dataframe, length=130, coef=0.2, vcoef=2.5, signalLength=5, smoothVFI=Fa
 
 
 def stc(dataframe, fast=23, slow=50, length=10):
-
     # First, the 23-period and the 50-period EMA and the MACD values are calculated:
     # EMA1 = EMA (Close, Short Length);
     # EMA2 = EMA (Close, Long Length);
@@ -998,7 +1009,6 @@ def VIDYA(dataframe, length=9, select=True):
 
     df["VIDYA"] = 0.0
     for i in range(length, len(df)):
-
         df["VIDYA"].iat[i] = (
             alpha * df["k"].iat[i] * df["close"].iat[i]
             + (1 - alpha * df["k"].iat[i]) * df["VIDYA"].iat[i - 1]
@@ -1208,3 +1218,53 @@ def PMAX(dataframe, period=10, multiplier=3, length=12, MAtype=1, src=1):  # noq
     df.fillna(0, inplace=True)
 
     return df
+
+
+def tv_wma(dataframe: DataFrame, length: int = 9, field="close") -> DataFrame:
+    """
+    Source: Tradingview "Moving Average Weighted"
+    Pinescript Author: Unknown
+
+    Args :
+        dataframe : Pandas Dataframe
+        length : WMA length
+        field : Field to use for the calculation
+
+    Returns :
+        dataframe : Pandas DataFrame with new columns 'tv_wma'
+    """
+
+    norm = 0
+    sum = 0
+
+    for i in range(1, length - 1):
+        weight = (length - i) * length
+        norm = norm + weight
+        sum = sum + dataframe[field].shift(i) * weight
+
+    dataframe["tv_wma"] = sum / norm
+    return dataframe
+
+
+def tv_hma(dataframe: DataFrame, length: int = 9, field="close") -> DataFrame:
+    """
+    Source: Tradingview "Hull Moving Average"
+    Pinescript Author: Unknown
+
+    Args :
+        dataframe : Pandas Dataframe
+        length : HMA length
+        field : Field to use for the calculation
+
+    Returns :
+        dataframe : Pandas DataFrame with new columns 'tv_hma'
+    """
+
+    dataframe["h"] = 2 * tv_wma(dataframe, math.floor(length / 2), field) - tv_wma(
+        dataframe, length, field=field
+    )
+
+    dataframe["tv_hma"] = tv_wma(dataframe, math.floor(math.sqrt(length)), field="h")
+    dataframe.drop("h", inplace=True, axis=1)
+
+    return dataframe
