@@ -35,6 +35,7 @@ def bollinger_bands(
 
 # DEMA                 Double Exponential Moving Average
 
+
 # EMA                  Exponential Moving Average
 def ema(dataframe: DataFrame, period: int, field="close") -> Series:
     """
@@ -55,6 +56,7 @@ def ema(dataframe: DataFrame, period: int, field="close") -> Series:
 # SAR                  Parabolic SAR
 # SAREXT               Parabolic SAR - Extended
 
+
 # SMA                  Simple Moving Average
 def sma(dataframe, period, field="close"):
     import talib.abstract as ta
@@ -64,6 +66,7 @@ def sma(dataframe, period, field="close"):
 
 # T3                   Triple Exponential Moving Average (T3)
 
+
 # TEMA                 Triple Exponential Moving Average
 def tema(dataframe, period, field="close"):
     import talib.abstract as ta
@@ -74,6 +77,7 @@ def tema(dataframe, period, field="close"):
 # TRIMA                Triangular Moving Average
 # WMA                  Weighted Moving Average
 
+
 # Other Overlap Studies Functions
 def hull_moving_average(dataframe, period, field="close") -> ndarray:
     # TODO: Remove this helper method, it's a 1:1 call to qtpylib's HMA.
@@ -82,8 +86,8 @@ def hull_moving_average(dataframe, period, field="close") -> ndarray:
     return hma(dataframe[field], period)
 
 
-def vwma(df, window):
-    return (df["close"] * df["volume"]).rolling(window).sum() / df.volume.rolling(window).sum()
+def vwma(df, window, price="close"):
+    return (df[price] * df["volume"]).rolling(window).sum() / df.volume.rolling(window).sum()
 
 
 def zema(dataframe, period, field="close"):
