@@ -1,4 +1,3 @@
-
 import freqtrade.vendor.qtpylib.indicators as qtpylib
 import pandas as pd
 
@@ -36,45 +35,31 @@ def pivots_points(dataframe: pd.DataFrame, timeperiod=30, levels=3) -> pd.DataFr
     data = {}
 
     low = qtpylib.rolling_mean(
-        series=pd.Series(
-            index=dataframe.index,
-            data=dataframe['low']
-        ),
-        window=timeperiod
+        series=pd.Series(index=dataframe.index, data=dataframe["low"]), window=timeperiod
     )
 
     high = qtpylib.rolling_mean(
-        series=pd.Series(
-            index=dataframe.index,
-            data=dataframe['high']
-        ),
-        window=timeperiod
+        series=pd.Series(index=dataframe.index, data=dataframe["high"]), window=timeperiod
     )
 
     # Pivot
-    data['pivot'] = qtpylib.rolling_mean(
-        series=qtpylib.typical_price(dataframe),
-        window=timeperiod
-    )
+    data["pivot"] = qtpylib.rolling_mean(series=qtpylib.typical_price(dataframe), window=timeperiod)
 
     # Resistance #1
-    data['r1'] = (2 * data['pivot']) - low
+    data["r1"] = (2 * data["pivot"]) - low
 
     # Resistance #2
-    data['s1'] = (2 * data['pivot']) - high
+    data["s1"] = (2 * data["pivot"]) - high
 
     # Calculate Resistances and Supports >1
-    for i in range(2, levels+1):
-        prev_support = data['s' + str(i - 1)]
-        prev_resistance = data['r' + str(i - 1)]
+    for i in range(2, levels + 1):
+        prev_support = data["s" + str(i - 1)]
+        prev_resistance = data["r" + str(i - 1)]
 
         # Resitance
-        data['r' + str(i)] = (data['pivot'] - prev_support) + prev_resistance
+        data["r" + str(i)] = (data["pivot"] - prev_support) + prev_resistance
 
         # Support
-        data['s' + str(i)] = data['pivot'] - (prev_resistance - prev_support)
+        data["s" + str(i)] = data["pivot"] - (prev_resistance - prev_support)
 
-    return pd.DataFrame(
-        index=dataframe.index,
-        data=data
-    )
+    return pd.DataFrame(index=dataframe.index, data=data)
